pub fn panic(error: BevyError, ctx: ErrorContext)Expand description
Error handler that panics with the system error. If panics are passed as errors these will be resumed.
pub fn panic(error: BevyError, ctx: ErrorContext)Error handler that panics with the system error. If panics are passed as errors these will be resumed.